

#include "SWF.h"
#include <string.h>

namespace SWF {


size_t Solid::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += color.getSize(ctx,r);

	
	r += Style::getHeaderSize( r-start_at );
//	printf("Solid sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LinearGradient::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += matrix.getSize(ctx,r);

	r += 8;

	{
		GradientItem* item;
		ListItem<GradientItem>* i;
		i = gradientColors.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Style::getHeaderSize( r-start_at );
//	printf("LinearGradient sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t RadialGradient::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += matrix.getSize(ctx,r);

	r += 8;

	{
		GradientItem* item;
		ListItem<GradientItem>* i;
		i = gradientColors.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Style::getHeaderSize( r-start_at );
//	printf("RadialGradient sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t TiledBitmap::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += matrix.getSize(ctx,r);

	
	r += Style::getHeaderSize( r-start_at );
//	printf("TiledBitmap sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ClippedBitmap::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += matrix.getSize(ctx,r);

	
	r += Style::getHeaderSize( r-start_at );
//	printf("ClippedBitmap sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t UnknownTag::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += len * 8;

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("UnknownTag sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t End::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Tag::getHeaderSize( r-start_at );
//	printf("End sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ShowFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Tag::getHeaderSize( r-start_at );
//	printf("ShowFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineShape::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->alpha = 0;

	ctx->many_shapes = 0;

	r += 16;

	r += bounds.getSize(ctx,r);

	r += styles.getSize(ctx,r);

	r += shapes.getSize(ctx,r);

	if( r%8 != 0 ) r += 8-(r%8);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineShape sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t RemoveObject::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 16;

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("RemoveObject sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineBits::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineBits sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetBackgroundColor::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->alpha = 0;

	r += color.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("SetBackgroundColor sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineText::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->glyphBits = glyphBits;

	ctx->advanceBits = advanceBits;

	r += 16;

	r += bounds.getSize(ctx,r);

	r += transform.getSize(ctx,r);

	r += 8;

	r += 8;

	ctx->alpha = 0;

	{
		TextRecord* item;
		ListItem<TextRecord>* i;
		i = records.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineText sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DoAction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	{
		Action* item;
		ListItem<Action>* i;
		i = actions.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DoAction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineFontInfo::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	r += nameLength * 8;

	r += 2;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	if( ctx->swfVersion>=6 ) {
		
	r += 8;

	}

	r += map.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineFontInfo sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineShape2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineShape2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineShape3::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->alpha = 1;

	ctx->many_shapes = 1;

	r += 16;

	r += bounds.getSize(ctx,r);

	r += styles.getSize(ctx,r);

	r += shapes.getSize(ctx,r);

	if( r%8 != 0 ) r += 8-(r%8);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineShape3 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineMorphShape::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineMorphShape sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineFontInfo2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	r += nameLength * 8;

	r += 2;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	if( ctx->swfVersion>=6 ) {
		
	r += 8;

	}

	r += map.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineFontInfo2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SoundStreamHead::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 4;

	r += 2;

	r++;

	r++;

	r += 4;

	r += 2;

	r++;

	r++;

	r += 16;

	if( compression==2 ) {
		
	r += latencySeek.getSize(ctx,r);

	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("SoundStreamHead sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineBitsLossless::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	r += 16;

	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineBitsLossless sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineBitsJPEG2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineBitsJPEG2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineBitsLossless2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	r += 16;

	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineBitsLossless2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t PlaceObject2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r += 16;

	if( hasID ) {
		
		
	r += 16;

	}

	if( hasTransform ) {
		
		
	r += transform.getSize(ctx,r);

	}

	if( hasColorTransform ) {
		
		
	r += colorTransform.getSize(ctx,r);

	}

	if( hasMorph ) {
		
		
	r += 16;

	}

	if( hasName ) {
		
		
	r += ((name ? strlen( name ) : 0)+1)*8;

	}

	if( hasClipDepth ) {
		
		
	r += 16;

	}

	if( hasEventHandler ) {
		
		
	r += events.getSize(ctx,r);

	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("PlaceObject2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t RemoveObject2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("RemoveObject2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineEditText::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->alpha = 1;

	r += 16;

	r += size.getSize(ctx,r);

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	if( hasFont ) {
		
		
	r += 16;

	r += 16;

	}

	if( hasColor ) {
		
		
	r += color.getSize(ctx,r);

	}

	if( hasMaxLength ) {
		
		
	r += 16;

	}

	if( hasLayout ) {
		
		
	r += 8;

	r += 16;

	r += 16;

	r += 16;

	r += 16;

	}

	r += ((variableName ? strlen( variableName ) : 0)+1)*8;

	if( hasText ) {
		
		
	r += ((initialText ? strlen( initialText ) : 0)+1)*8;

	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineEditText sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineSprite::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 16;

	{
		Tag* item;
		ListItem<Tag>* i;
		i = tags.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineSprite sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t FrameLabel::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((label ? strlen( label ) : 0)+1)*8;

	r += flags.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("FrameLabel sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SoundStreamHead2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 4;

	r += 2;

	r++;

	r++;

	r += 4;

	r += 2;

	r++;

	r++;

	r += 16;

	if( compression==2 ) {
		
	r += latencySeek.getSize(ctx,r);

	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("SoundStreamHead2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineFont::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->tagVersion = 1;

	ctx->wideGlyphOffsets = 0;

	r += 16;

	r += glyphs.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineFont sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineFont2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	ctx->wideGlyphOffsets = wideGlyphOffsets;

	ctx->wideMap = wideMap;

	ctx->glyphCount = glyphCount;

	ctx->tagVersion = 2;

	r += 16;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r += 8;

	r += ((name ? strlen( name ) : 0)+1)*8;

	r += 16;

	r += glyphs.getSize(ctx,r);

	if( hasLayout ) {
		
		
	r += 16;

	r += 16;

	r += 16;

	{
		Short* item;
		ListItem<Short>* i;
		i = advance.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	{
		Rectangle* item;
		ListItem<Rectangle>* i;
		i = bounds.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	r += 16;

	if( wideMap ) {
		
		
	{
		WideKerning* item;
		ListItem<WideKerning>* i;
		i = wideKerning.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	}

	if( !wideMap ) {
		
		
	{
		Kerning* item;
		ListItem<Kerning>* i;
		i = kerning.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	}

	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineFont2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineButton2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 7;

	r++;

	r += 16;

	{
		Button* item;
		ListItem<Button>* i;
		i = buttons.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	{
		Condition* item;
		ListItem<Condition>* i;
		i = conditions.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineButton2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Export::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	{
		Symbol* item;
		ListItem<Symbol>* i;
		i = symbols.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("Export sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Import::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((url ? strlen( url ) : 0)+1)*8;

	r += 16;

	{
		Symbol* item;
		ListItem<Symbol>* i;
		i = symbols.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("Import sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DoInitAction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	{
		Action* item;
		ListItem<Action>* i;
		i = actions.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DoInitAction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SoundStreamBlock::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += len * 8;

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("SoundStreamBlock sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineVideoStream::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 16;

	r += 16;

	r += 16;

	r += 5;

	r += 2;

	r++;

	r += 8;

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("DefineVideoStream sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t VideoFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 16;

	r += data.getSize(ctx,r);

	
	r += Tag::getHeaderSize( r-start_at );
//	printf("VideoFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackString::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((value ? strlen( value ) : 0)+1)*8;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackString sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackFloat::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 32;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackFloat sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackNull::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackNull sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackUndefined::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackUndefined sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackRegister::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackRegister sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackBoolean::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackBoolean sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackDouble::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 64;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackDouble sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackInteger::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 32;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackInteger sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackDictionaryLookup::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackDictionaryLookup sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StackLargeDictionaryLookup::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += StackItem::getHeaderSize( r-start_at );
//	printf("StackLargeDictionaryLookup sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t UnknownAction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += len * 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("UnknownAction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t EndAction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("EndAction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t NextFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("NextFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t PreviousFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("PreviousFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Play::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Play sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Stop::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Stop sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ToggleQuality::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ToggleQuality sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StopSound::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StopSound sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t AddCast::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("AddCast sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Substract::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Substract sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Mulitply::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Mulitply sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Divide::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Divide sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t EqualCast::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("EqualCast sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LessThanCast::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("LessThanCast sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LogicalAND::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("LogicalAND sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LogicalOR::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("LogicalOR sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LogicalNOT::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("LogicalNOT sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StringEqual::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StringEqual sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StringLength::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StringLength sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SubString::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SubString sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Pop::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Pop sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t IntegralPart::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("IntegralPart sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetVariable::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetVariable sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetVariable::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetVariable sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetTargetDynamic::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetTargetDynamic sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ConcatenateString::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ConcatenateString sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetProperty::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetProperty sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetProperty::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetProperty sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DuplicateSprite::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DuplicateSprite sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t RemoveSprite::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("RemoveSprite sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Trace::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Trace sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StartDrag::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StartDrag sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StopDrag::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StopDrag sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StringLessThan::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StringLessThan sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Throw::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Throw sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t CastObject::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("CastObject sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Implements::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Implements sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Random::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Random sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t MultibyteStringLength::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("MultibyteStringLength sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ORD::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ORD sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t CHR::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("CHR sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetTimer::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetTimer sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t MultibyteSubString::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("MultibyteSubString sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t MultibyteORD::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("MultibyteORD sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t MultibyteCHR::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("MultibyteCHR sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Delete::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Delete sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeleteAll::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeleteAll sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetLocalVariable::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetLocalVariable sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t CallFunction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("CallFunction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Return::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Return sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Modulo::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Modulo sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t New::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("New sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeclareLocalVariable::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeclareLocalVariable sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeclareArray::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeclareArray sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeclareObject::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeclareObject sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t TypeOf::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("TypeOf sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetTarget::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetTarget sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Enumerate::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Enumerate sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t AddTyped::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("AddTyped sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t LessThanTyped::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("LessThanTyped sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t EqualTyped::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("EqualTyped sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineNumber::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DefineNumber sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DefineString::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("DefineString sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Duplicate::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Duplicate sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Swap::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Swap sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetMember::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetMember sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetMember::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetMember sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Increment::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Increment sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Decrement::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Decrement sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t CallMethod::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("CallMethod sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t NewMethod::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("NewMethod sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t InstanceOf::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("InstanceOf sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t EnumerateObject::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("EnumerateObject sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t AND::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("AND sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t OR::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("OR sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t XOR::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("XOR sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ShiftLeft::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ShiftLeft sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ShiftRight::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ShiftRight sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t ShiftRightUnsigned::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("ShiftRightUnsigned sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StrictEqual::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StrictEqual sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GreaterThanTyped::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("GreaterThanTyped sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StringGreaterThan::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("StringGreaterThan sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Extends::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("Extends sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GotoFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("GotoFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetURL::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((url ? strlen( url ) : 0)+1)*8;

	r += ((target ? strlen( target ) : 0)+1)*8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetURL sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t StoreRegister::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("StoreRegister sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Dictionary::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	{
		String* item;
		ListItem<String>* i;
		i = strings.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Action::getHeaderSize( r-start_at );
//	printf("Dictionary sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t WaitForFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("WaitForFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t SetTarget::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((label ? strlen( label ) : 0)+1)*8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("SetTarget sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GotoLabel::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((label ? strlen( label ) : 0)+1)*8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("GotoLabel sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t WaitForFrameDynamic::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	r += 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("WaitForFrameDynamic sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeclareFunction2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((name ? strlen( name ) : 0)+1)*8;

	r += 16;

	r += 8;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r += 7;

	{
		Parameter* item;
		ListItem<Parameter>* i;
		i = args.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	r += 16;

	{
		Action* item;
		ListItem<Action>* i;
		i = actions.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeclareFunction2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Try::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 5;

	r++;

	r++;

	r++;

	r += 16;

	r += 16;

	r += 16;

	if( catchInRegister ) {
		
		
	r += 8;

	}

	
	r += Action::getHeaderSize( r-start_at );
//	printf("Try sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t With::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("With sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t PushData::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	{
		StackItem* item;
		ListItem<StackItem>* i;
		i = items.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
	r += Action::getHeaderSize( r-start_at );
//	printf("PushData sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GetURL2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("GetURL2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t DeclareFunction::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += ((name ? strlen( name ) : 0)+1)*8;

	r += 16;

	{
		String* item;
		ListItem<String>* i;
		i = args.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	r += 16;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("DeclareFunction sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t BranchAlways::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("BranchAlways sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t BranchIfTrue::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 16;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("BranchIfTrue sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t CallFrame::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	
	r += Action::getHeaderSize( r-start_at );
//	printf("CallFrame sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t GotoExpression::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;
	
	r += 8;

	
	r += Action::getHeaderSize( r-start_at );
//	printf("GotoExpression sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );

	return r-start_at;
}

size_t Rectangle::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 5;

	r += bits;

	r += bits;

	r += bits;

	r += bits;

	if( r%8 != 0 ) r += 8-(r%8);

	
//	printf("Rectangle sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Color::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 8;

	r += 8;

	r += 8;

	if( ctx->alpha ) {
		
	r += 8;

	}

	if( r%8 != 0 ) r += 8-(r%8);

	
//	printf("Color sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t String::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += ((value ? strlen( value ) : 0)+1)*8;

	
//	printf("String sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Transform::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r++;

	if( scaled ) {
		
		
	r += 5;

	r += bitsScale;

	r += bitsScale;

	}

	r++;

	if( skewed ) {
		
		
	r += 5;

	r += bitsSkew;

	r += bitsSkew;

	}

	r += 5;

	r += bitsTranslate;

	r += bitsTranslate;

	if( r%8 != 0 ) r += 8-(r%8);

	
//	printf("Transform sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t ColorTransform2::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r++;

	r++;

	r += 4;

	if( hasFactor ) {
		
		
	r += bits;

	r += bits;

	r += bits;

	r += bits;

	}

	if( hasOffset ) {
		
		
	r += bits;

	r += bits;

	r += bits;

	r += bits;

	}

	if( r%8 != 0 ) r += 8-(r%8);

	
//	printf("ColorTransform2 sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Header::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += size.getSize(ctx,r);

	r += 16;

	r += 16;

	{
		Tag* item;
		ListItem<Tag>* i;
		i = tags.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
//	printf("Header sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t LineStyle::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	r += color.getSize(ctx,r);

	
//	printf("LineStyle sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t StyleList::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	ctx->fillBits = fillBits;

	ctx->lineBits = lineBits;

	r += 8;

	{
		Style* item;
		ListItem<Style>* i;
		i = fillStyles.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	r += 8;

	{
		LineStyle* item;
		ListItem<LineStyle>* i;
		i = lineStyles.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	r += 4;

	r += 4;

	
//	printf("StyleList sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t ShapeSetup::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += ShapeItem::getHeaderSize( r-start_at );

	
	r++;

	r++;

	r++;

	r++;

	r++;

	if( hasMoveTo ) {
		
		
	r += 5;

	r += xybits;

	r += xybits;

	}

	if( hasFillStyle0 ) {
		
		
	r += ctx->fillBits;

	}

	if( hasFillStyle1 ) {
		
		
	r += ctx->fillBits;

	}

	if( hasLineStyle ) {
		
		
	r += ctx->lineBits;

	}

	if( hasNewStyles ) {
		
		
	if( r%8 != 0 ) r += 8-(r%8);

	r += styles.getSize(ctx,r);

	}

	
//	printf("ShapeSetup sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t CurveTo::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += ShapeItem::getHeaderSize( r-start_at );

	
	r += 4;

	r += bits+2;

	r += bits+2;

	r += bits+2;

	r += bits+2;

	
//	printf("CurveTo sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Shape::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	{
		ShapeItem* item;
		ListItem<ShapeItem>* i;
		i = edges.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
//	printf("Shape sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t GlyphShape::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	ctx->fillBits = 1;

	ctx->lineBits = 0;

	r += 4;

	r += 4;

	{
		ShapeItem* item;
		ListItem<ShapeItem>* i;
		i = edges.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
//	printf("GlyphShape sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t GradientItem::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 8;

	r += color.getSize(ctx,r);

	
//	printf("GradientItem sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Symbol::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	r += ((name ? strlen( name ) : 0)+1)*8;

	
//	printf("Symbol sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Parameter::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 8;

	r += ((name ? strlen( name ) : 0)+1)*8;

	
//	printf("Parameter sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t UChar::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 8;

	
//	printf("UChar sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t UShort::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	
//	printf("UShort sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t ULong::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 32;

	
//	printf("ULong sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Short::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	
//	printf("Short sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Kerning::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 8;

	r += 8;

	
//	printf("Kerning sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t WideKerning::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	r += 16;

	
//	printf("WideKerning sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t TextEntry::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += ctx->glyphBits;

	r += ctx->advanceBits;

	
//	printf("TextEntry sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t TextRecord6::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r++;

	if( isSetup ) {
		
		
	r += 3;

	r++;

	r++;

	r++;

	r++;

	if( hasFont ) {
		
		
	r += 16;

	}

	if( hasColor ) {
		
		
	r += color.getSize(ctx,r);

	}

	if( hasMoveX ) {
		
		
	r += 16;

	}

	if( hasMoveY ) {
		
		
	r += 16;

	}

	if( hasFont ) {
		
		
	r += 16;

	}

	}

	if( !isSetup ) {
		
		
	r += 7;

	{
		TextEntry* item;
		ListItem<TextEntry>* i;
		i = glyphs.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	if( r%8 != 0 ) r += 8-(r%8);

	}

	
//	printf("TextRecord6 sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t TextRecord7::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r++;

	r += 3;

	r++;

	r++;

	r++;

	r++;

	if( hasFont ) {
		
		
	r += 16;

	}

	if( hasColor ) {
		
		
	r += color.getSize(ctx,r);

	}

	if( hasMoveX ) {
		
		
	r += 16;

	}

	if( hasMoveY ) {
		
		
	r += 16;

	}

	if( hasFont ) {
		
		
	r += 16;

	}

	if( isSetup ) {
		
		
	r += 8;

	{
		TextEntry* item;
		ListItem<TextEntry>* i;
		i = glyphs.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	}

	if( r%8 != 0 ) r += 8-(r%8);

	
//	printf("TextRecord7 sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t TextRecord::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	if( ctx->swfVersion < 7 ) {
		
	{
		TextRecord6* item;
		ListItem<TextRecord6>* i;
		i = records.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	}

	if( ctx->swfVersion >= 7 ) {
		
	r += string.getSize(ctx,r);

	}

	
//	printf("TextRecord sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Button::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 4;

	r++;

	r++;

	r++;

	r++;

	if( hitTest || down || over || up ) {
		
	r += 16;

	r += 16;

	r += transform.getSize(ctx,r);

	r += colorTransform.getSize(ctx,r);

	}

	
//	printf("Button sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}

size_t Condition::getSize( Context *ctx, int start_at ) {
	size_t r = start_at;

	r += Item::getHeaderSize( r-start_at );

	
	r += 16;

	r += 7;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	r++;

	{
		Action* item;
		ListItem<Action>* i;
		i = actions.first();
		while( i ) {
			item = i->data();
			if( item ) {
				r += item->getSize(ctx,r);
			}
			i = i->next();
		}
	}

	
//	printf("Condition sz %i bits (%.2f bytes)\n", r-start_at, ((float)r-start_at)/8 );

	return r-start_at;
}


}

